mlbench_core.lr_scheduler
-------------------------
.. autoapimodule:: mlbench_core.lr_scheduler
.. currentmodule:: mlbench_core.lr_scheduler

pytorch
~~~~~~~

.. autoapimodule:: mlbench_core.lr_scheduler.pytorch.lr
.. currentmodule:: mlbench_core.lr_scheduler.pytorch.lr

SparsifiedSGDLR
+++++++++++++++

.. autoapiclass:: SparsifiedSGDLR
    :members:


triangular_learning_rates
+++++++++++++++++++++++++

.. autoapifunction:: triangular_learning_rates

cyclical_learning_rates
+++++++++++++++++++++++

.. autoapifunction:: cyclical_learning_rates

multistep_learning_rates_with_warmup
++++++++++++++++++++++++++++++++++++

.. autoapifunction:: multistep_learning_rates_with_warmup


.. rubric:: References


.. bibliography:: lr_scheduler.bib
   :cited:


tensorflow
~~~~~~~~~~

.. autoapimodule:: mlbench_core.lr_scheduler.tensorflow
.. currentmodule:: mlbench_core.lr_scheduler.tensorflow

manual_stepping
+++++++++++++++

.. autoapifunction:: manual_stepping
